@@ -18,8 +18,9 @@
 import importlib
 import pprint
 import textwrap
+from dataclasses import dataclass
 from types import ModuleType
-from typing import Any, Dict, Iterable, NamedTuple, Optional, Tuple, Type
+from typing import Any, Dict, Iterable, Optional, Tuple, Type, Union
 
 import gitlab
 from gitlab import types as g_types
@@ -41,7 +42,7 @@ _URL_ATTRIBUTE_ERROR = (
 )
 
 
-class RESTObject(object):
+class RESTObject:
     """Represents an object built from server data.
 
     It holds the attributes know from the server, and the updated attributes in
@@ -167,21 +168,21 @@ class RESTObject(object):
             return NotImplemented
         if self.get_id() and other.get_id():
             return self.get_id() == other.get_id()
-        return super(RESTObject, self) == other
+        return super() == other
 
     def __ne__(self, other: object) -> bool:
         if not isinstance(other, RESTObject):
             return NotImplemented
         if self.get_id() and other.get_id():
             return self.get_id() != other.get_id()
-        return super(RESTObject, self) != other
+        return super() != other
 
     def __dir__(self) -> Iterable[str]:
-        return set(self.attributes).union(super(RESTObject, self).__dir__())
+        return set(self.attributes).union(super().__dir__())
 
     def __hash__(self) -> int:
         if not self.get_id():
-            return super(RESTObject, self).__hash__()
+            return super().__hash__()
         return hash(self.get_id())
 
     def _create_managers(self) -> None:
@@ -211,14 +212,14 @@ class RESTObject(object):
         self.__dict__["_updated_attrs"] = {}
         self.__dict__["_attrs"] = new_attrs
 
-    def get_id(self) -> Any:
+    def get_id(self) -> Optional[Union[int, str]]:
         """Returns the id of the resource."""
         if self._id_attr is None or not hasattr(self, self._id_attr):
             return None
         return getattr(self, self._id_attr)
 
     @property
-    def encoded_id(self) -> Any:
+    def encoded_id(self) -> Optional[Union[int, str]]:
         """Ensure that the ID is url-encoded so that it can be safely used in a URL
         path"""
         obj_id = self.get_id()
@@ -234,7 +235,7 @@ class RESTObject(object):
         return d
 
 
-class RESTObjectList(object):
+class RESTObjectList:
     """Generator object representing a list of RESTObject's.
 
     This generator uses the Gitlab pagination system to fetch new data when
@@ -316,12 +317,13 @@ class RESTObjectList(object):
         return self._list.total
 
 
-class RequiredOptional(NamedTuple):
-    required: Tuple[str, ...] = tuple()
-    optional: Tuple[str, ...] = tuple()
+@dataclass(frozen=True)
+class RequiredOptional:
+    required: Tuple[str, ...] = ()
+    optional: Tuple[str, ...] = ()
 
 
-class RESTManager(object):
+class RESTManager:
     """Base class for CRUD operations on objects.
 
     Derived class must define ``_path`` and ``_obj_cls``.
