@@ -100,6 +100,7 @@ def test_groups(gl):
     member = group1.members.get(user2.id)
     assert member.access_level == gitlab.const.OWNER_ACCESS
 
+    gl.auth()
     group2.members.delete(gl.user.id)
 
 
@@ -198,6 +199,11 @@ def test_group_subgroups_projects(gl, user):
     assert gr1_project.namespace["id"] == group1.id
     assert gr2_project.namespace["parent_id"] == group1.id
 
+    gr1_project.delete()
+    gr2_project.delete()
+    group3.delete()
+    group4.delete()
+
 
 @pytest.mark.skip
 def test_group_wiki(group):
@@ -225,3 +231,21 @@ def test_group_hooks(group):
     hook = group.hooks.get(hook.id)
     assert hook.note_events is True
     hook.delete()
+
+
+def test_group_transfer(gl, group):
+    transfer_group = gl.groups.create(
+        {"name": "transfer-test-group", "path": "transfer-test-group"}
+    )
+    transfer_group = gl.groups.get(transfer_group.id)
+    assert transfer_group.parent_id != group.id
+
+    transfer_group.transfer(group.id)
+
+    transferred_group = gl.groups.get(transfer_group.id)
+    assert transferred_group.parent_id == group.id
+
+    transfer_group.transfer()
+
+    transferred_group = gl.groups.get(transfer_group.id)
+    assert transferred_group.path == transferred_group.full_path
