@@ -32,6 +32,22 @@ def test_merge_requests(project):
     )
 
 
+def test_merge_requests_get(project, merge_request):
+    new_mr = merge_request(source_branch="test_get")
+    mr_iid = new_mr.iid
+    mr = project.mergerequests.get(mr_iid)
+    assert mr.iid == mr_iid
+    mr = project.mergerequests.get(str(mr_iid))
+    assert mr.iid == mr_iid
+
+
+def test_merge_requests_get_lazy(project, merge_request):
+    new_mr = merge_request(source_branch="test_get")
+    mr_iid = new_mr.iid
+    mr = project.mergerequests.get(mr_iid, lazy=True)
+    assert mr.iid == mr_iid
+
+
 def test_merge_request_discussion(project):
     mr = project.mergerequests.list()[0]
     size = len(mr.discussions.list())
@@ -154,7 +170,9 @@ def test_merge_request_large_commit_message(
     merge_commit_message = "large_message\r\n" * 1_000
     assert len(merge_commit_message) > 10_000
 
-    mr.merge(merge_commit_message=merge_commit_message)
+    mr.merge(
+        merge_commit_message=merge_commit_message, should_remove_source_branch=False
+    )
 
     result = wait_for_sidekiq(timeout=60)
     assert result is True, "sidekiq process should have terminated but did not"
