@@ -106,12 +106,11 @@ def test_project_file_uploads(project):
     file_contents = "testing contents"
 
     uploaded_file = project.upload(filename, file_contents)
-    assert uploaded_file["alt"] == filename
-    assert uploaded_file["url"].startswith("/uploads/")
-    assert uploaded_file["url"].endswith(f"/{filename}")
-    assert uploaded_file["markdown"] == "[{}]({})".format(
-        uploaded_file["alt"], uploaded_file["url"]
-    )
+    alt, url = uploaded_file["alt"], uploaded_file["url"]
+    assert alt == filename
+    assert url.startswith("/uploads/")
+    assert url.endswith(f"/{filename}")
+    assert uploaded_file["markdown"] == f"[{alt}]({url})"
 
 
 def test_project_forks(gl, project, user):
@@ -328,18 +327,18 @@ def test_project_groups_list(gl, group):
 
     groups = project.groups.list()
     group_ids = set([x.id for x in groups])
-    assert set((group.id, group2.id)) == group_ids
+    assert {group.id, group2.id} == group_ids
 
 
 def test_project_transfer(gl, project, group):
     assert project.namespace["path"] != group.full_path
-    project.transfer_project(group.id)
+    project.transfer(group.id)
 
     project = gl.projects.get(project.id)
     assert project.namespace["path"] == group.full_path
 
     gl.auth()
-    project.transfer_project(gl.user.username)
+    project.transfer(gl.user.username)
 
     project = gl.projects.get(project.id)
     assert project.namespace["path"] == gl.user.username
